<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en" sourcelanguage="en">
<context>
    <name>GTest</name>
    <message>
        <location filename="../src/Primer3Tests.cpp" line="331"/>
        <source>Contradiction in primer_task definition</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Tests.cpp" line="319"/>
        <source>Unrecognized PRIMER_TASK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Tests.cpp" line="184"/>
        <source>Illegal TARGET value: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Tests.cpp" line="202"/>
        <location filename="../src/Primer3Tests.cpp" line="270"/>
        <source>Illegal PRIMER_DEFAULT_PRODUCT value: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Tests.cpp" line="220"/>
        <source>Illegal PRIMER_INTERNAL_OLIGO_EXCLUDED_REGION value: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Tests.cpp" line="235"/>
        <source>Illegal INCLUDED_REGION value: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Tests.cpp" line="288"/>
        <source>Illegal EXCLUDED_REGION value: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Tests.cpp" line="389"/>
        <source>Missing SEQUENCE tag</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Tests.cpp" line="396"/>
        <source>Error in sequence quality data</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Tests.cpp" line="398"/>
        <source>Sequence quality data missing</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Tests.cpp" line="421"/>
        <source>PRIMER_PAIRS_NUMBER is incorrect. Expected:%2, but Actual:%3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Tests.cpp" line="523"/>
        <source>%1 is incorrect. Expected:%2,%3, but Actual:NULL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Tests.cpp" line="532"/>
        <source>%1 is incorrect. Expected:NULL, but Actual:%2,%3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Tests.cpp" line="542"/>
        <source>%1 is incorrect. Expected:%2,%3, but Actual:%4,%5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Tests.cpp" line="581"/>
        <location filename="../src/Primer3Tests.cpp" line="591"/>
        <location filename="../src/Primer3Tests.cpp" line="601"/>
        <source>%1 is incorrect. Expected:%2, but Actual:%3</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Primer3Dialog</name>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="20"/>
        <source>dialog_tittle</source>
        <translation>Primer designer</translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="36"/>
        <source>Main</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="44"/>
        <source>Excluded Regions</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="51"/>
        <source>Targets</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="101"/>
        <source>Product Size Ranges</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="111"/>
        <source>Mispriming/Repeat Library</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="136"/>
        <source>Number To Return</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="143"/>
        <source>Max Repeat Mispriming</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="150"/>
        <source>Max Template Mispriming</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="157"/>
        <source>Max 3&apos; Stability</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="164"/>
        <source>Pair Max Repeat Mispriming</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="171"/>
        <source>Pair Max Template Mispriming</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="217"/>
        <source>Start Codon Position</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="361"/>
        <source>Pick left primer</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="374"/>
        <source>or use left primer below</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="391"/>
        <source>Pick hybridization probe</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="404"/>
        <source>(internal oligo), or use oligo below</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="424"/>
        <source>Pick right primer or use right primer</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="437"/>
        <source>below (5&apos; to 3&apos; on opposite strand)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="467"/>
        <source>General Settings</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="475"/>
        <source>Primer Size</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="482"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="536"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="595"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="649"/>
        <source>Min</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="489"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="543"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="602"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="656"/>
        <source>Opt</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="496"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="550"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="609"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="663"/>
        <source>Max</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="529"/>
        <source>Primer Tm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="557"/>
        <source>Max Tm Difference</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="564"/>
        <source>Table of thermodynamic parameters</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="575"/>
        <source>Breslauer et. al 1986</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="580"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="1043"/>
        <source>SantaLucia 1998</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="588"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="2229"/>
        <source>Product Tm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="642"/>
        <source>Primer GC%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="957"/>
        <source>Max Self Complementarity</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="964"/>
        <source>Max 3&apos; Self Complementarity</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="971"/>
        <source>Inside Target Penalty</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="978"/>
        <source>Outside Target Penalty</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="985"/>
        <source>Concentration of monovalent cations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="992"/>
        <source>Max #N&apos;s</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="999"/>
        <source>Max Poly-X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1006"/>
        <source>First Base Index</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1013"/>
        <source>CG Clamp</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1020"/>
        <source>Concentration of divalent cations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1027"/>
        <source>Salt correction formula</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1038"/>
        <source>Schildkraut and Lifson 1965</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1048"/>
        <source>Owczarzy et. 2004</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1056"/>
        <source>Concentration of dNTPs</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1063"/>
        <source>Annealing Oligo Concentration</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1335"/>
        <source> Liberal Base</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1348"/>
        <source>Show Debuging Info</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1355"/>
        <source>Do not treat ambiguity codes in libraries as consensus</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1365"/>
        <source>Lowercase masking</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1375"/>
        <source>Internal Oligo</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1383"/>
        <source>Hyb Oligo Excluded Region</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1404"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="2513"/>
        <source>Hyb Oligo Size</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1411"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="2506"/>
        <source>Hyb Oligo Tm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1418"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="2520"/>
        <source>Hyb Oligo GC%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1425"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="1432"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="1439"/>
        <source>Min:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1485"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="1492"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="1499"/>
        <source>Opt:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1535"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="1542"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="1549"/>
        <source>Max:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1597"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="2658"/>
        <source>Hyb Oligo Self Complementarity</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1604"/>
        <source>Max #Ns</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1611"/>
        <source>Hyb Oligo Mishyb Library</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1618"/>
        <source>Hyb Oligo Min Sequence Quality</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1625"/>
        <source>Hyb Oligo Conc of monovalent cations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1632"/>
        <source>Hyb Oligo conc of divalent cations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1714"/>
        <source>Hyb Oligo Max 3&apos; Self Complementarity</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1721"/>
        <source>Hyb Oligo Max Poly-X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1728"/>
        <source>Hyb Oligo Max Mishyb</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1774"/>
        <source>Hyb Oligo [dNTP]</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1781"/>
        <source>Hyb Oligo DNA Concentration</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1830"/>
        <source>Penalty Weights</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1838"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt; font-weight:600;&quot;&gt;For Primers&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1851"/>
        <source>Tm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1858"/>
        <source>Size  </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1865"/>
        <source>GC%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1872"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="1879"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="1886"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="2262"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="2269"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="2527"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="2534"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="2541"/>
        <source>Lt:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="1932"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="1939"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="1946"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="2276"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="2283"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="2587"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="2594"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="2601"/>
        <source>Gt:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2003"/>
        <source>Self Complementarity</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2010"/>
        <source>3&apos; Self Complementarity</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2017"/>
        <source>#N&apos;s</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2024"/>
        <source>Mispriming</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2031"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="2756"/>
        <location filename="../src/ui/Primer3Dialog.ui" line="2762"/>
        <source>Sequence Quality</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2038"/>
        <source>End Sequence Quality</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2045"/>
        <source>Position Penalty</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2052"/>
        <source>End Stability</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2059"/>
        <source>Template Mispriming</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2209"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt; font-weight:600;&quot;&gt;For Primer Pairs&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2222"/>
        <source>Product Size</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2327"/>
        <source>Tm Difference</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2334"/>
        <source>Any Complementarity</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2341"/>
        <source>3&apos; Complementarity</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2348"/>
        <source>Pair Mispriming</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2355"/>
        <source>Primer Penalty Weight</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2362"/>
        <source>Hyb Oligo Penalty Weight</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2369"/>
        <source>Primer Pair Template Mispriming Weight</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2493"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt; font-weight:600;&quot;&gt;For Hyb Oligos&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2665"/>
        <source>Hyb Oligo #N&apos;s</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2672"/>
        <source>Hyb Oligo Mishybing</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2679"/>
        <source>Hyb Oligo Sequence Quality</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2774"/>
        <source>Min Sequence Quality:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2794"/>
        <source>Min End Sequence Quality:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2814"/>
        <source>Sequence Quality Range Min:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2834"/>
        <source>Sequence Quality Range Max:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2857"/>
        <source>Result Settings</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2892"/>
        <source>Range Start:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2909"/>
        <source>Range End:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2926"/>
        <source>Selection range</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2933"/>
        <source>Sequence range</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2953"/>
        <source>Reset Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/Primer3Dialog.ui" line="2960"/>
        <source>Pick Primers</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/Primer3Query.cpp" line="173"/>
        <source>Primer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Primer3Query.cpp" line="174"/>
        <source>PCR primer design</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Primer3Query.cpp" line="176"/>
        <source>Excluded regions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Primer3Query.cpp" line="177"/>
        <source>Targets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Primer3Query.cpp" line="178"/>
        <source>Product size ranges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Primer3Query.cpp" line="179"/>
        <source>Number to return</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Primer3Query.cpp" line="181"/>
        <source>Max repeat mispriming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Primer3Query.cpp" line="182"/>
        <source>Max template mispriming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Primer3Query.cpp" line="183"/>
        <source>Max 3&apos; stability</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Primer3Query.cpp" line="184"/>
        <source>Pair max repeat mispriming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Primer3Query.cpp" line="185"/>
        <source>Pair max template mispriming</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::Primer3ADVContext</name>
    <message>
        <location filename="../src/Primer3Plugin.cpp" line="110"/>
        <source>Primer3...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::Primer3Dialog</name>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="39"/>
        <source>NONE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="40"/>
        <source>HUMAN</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="41"/>
        <source>RODENT_AND_SIMPLE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="42"/>
        <source>RODENT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="43"/>
        <source>DROSOPHILA</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="330"/>
        <source>Start Codon Position</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="344"/>
        <source>Product Min Tm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="358"/>
        <source>Product Opt Tm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="372"/>
        <source>Product Max Tm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="386"/>
        <source>Opt GC%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="400"/>
        <source>Inside Penalty</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="414"/>
        <source>Internal Oligo Opt Tm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="426"/>
        <source>Excluded Regions</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="438"/>
        <source>Internal Oligo Excluded Regions</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="450"/>
        <source>Targets</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="462"/>
        <source>Product Size Ranges</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="499"/>
        <source>Sequence Quality</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="506"/>
        <source>Sequence quality list length must be equal to the sequence length</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="528"/>
        <source>Can&apos;t pick hyb oligo and only one primer</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="548"/>
        <source>Nothing to pick</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Dialog.cpp" line="567"/>
        <source>The field &apos;%1&apos; has invalid value</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::Primer3Plugin</name>
    <message>
        <location filename="../src/Primer3Plugin.cpp" line="34"/>
        <source>Primer3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/Primer3Plugin.cpp" line="34"/>
        <source>Integrated tool for PCR primers design.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::Primer3Task</name>
    <message>
        <location filename="../src/Primer3Task.cpp" line="309"/>
        <source>Pick primers task</source>
        <translation>Pick primers</translation>
    </message>
</context>
<context>
    <name>U2::Primer3ToAnnotationsTask</name>
    <message>
        <location filename="../src/Primer3Task.cpp" line="541"/>
        <source>Search primers to annotations</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::QDPrimerActor</name>
    <message>
        <location filename="../src/Primer3Query.cpp" line="62"/>
        <source>%1 invalid input. Excluded regions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Primer3Query.cpp" line="72"/>
        <source>%1 invalid input. Targets.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Primer3Query.cpp" line="82"/>
        <source>%1 invalid input. Product size ranges.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
